This is an automated email from the git hooks/post-receive script.

js pushed a commit to branch master
in repository libcatmandu-perl.

commit 3cbb367ae7d97785111c4e782f1256dc4ba5ff71
Author: Patrick Hochstenbach <patrick.hochstenb...@ugent.be>
Date:   Tue Jan 26 11:21:38 2016 +0100

    Making more sense of the POD
---
 lib/Catmandu/Fix/retain.pm | 14 ++++++++------
 1 file changed, 8 insertions(+), 6 deletions(-)

diff --git a/lib/Catmandu/Fix/retain.pm b/lib/Catmandu/Fix/retain.pm
index a5062e9..0fa78b0 100644
--- a/lib/Catmandu/Fix/retain.pm
+++ b/lib/Catmandu/Fix/retain.pm
@@ -56,12 +56,14 @@ Catmandu::Fix::retain - delete everything except the paths 
given
 
 =head1 SYNOPSIS
 
-   # Delete everything except foo.bar and baz.bar
-   retain(foo.bar, bar.baz)
-
-   {bar => { x => 1} , foo => {bar => 1, y => 2}}
-   # becomes
-   {foo => {bar => 1}}
+   # Keep the field _id , name , title
+   retain(_id , name, title)
+
+   # Delete everything except foo.bar 
+   #   {bar => { x => 1} , foo => {bar => 1, y => 2}}
+   # to
+   #   {foo => {bar => 1}}
+   retain(foo.bar)
 
 =head1 SEE ALSO
 

-- 
Alioth's /usr/local/bin/git-commit-notice on 
/srv/git.debian.org/git/pkg-perl/packages/libcatmandu-perl.git

_______________________________________________
Pkg-perl-cvs-commits mailing list
Pkg-perl-cvs-commits@lists.alioth.debian.org
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-perl-cvs-commits

Reply via email to